@@ -4,7 +4,7 @@ from django.core.urlresolvers import reverse
 from django.utils.feedgenerator import Atom1Feed
 from django.utils.html import strip_tags
 
-from mezzanine.blog.models import BlogPost
+from mezzanine.blog.models import BlogPost, BlogCategory
 from mezzanine.blog.views import blog_page
 
 
@@ -23,7 +23,23 @@ class PostsRSS(Feed):
         return reverse("blog_post_feed", kwargs={"url": "rss"})
 
     def items(self):
-        return BlogPost.objects.published()
+        return BlogPost.objects.published().select_related("user")
+
+    def categories(self):
+        return BlogCategory.objects.all()
+
+    def item_author_name(self, item):
+        return item.user.get_full_name() or item.user.username
+
+    def item_author_link(self, item):
+        username = item.user.username
+        return reverse("blog_post_list_author", kwargs={"username": username})
+
+    def item_pubdate(self, item):
+        return item.publish_date
+
+    def item_categories(self, item):
+        return item.categories.all()
 
 
 class PostsAtom(PostsRSS):
